//Copyright (C) 2004, Brian Enigma <enigma at netninja.com>
//This file is part of MagicCodes.
//
//MagicCodes is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//MagicCodes is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with Foobar; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
package org.ninjasoft.magiccodes.logic;

import java.util.*;
import org.ninjasoft.magiccodes.plugins.*;

/**
 * @author enigma
 *
 * To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Generation - Code and Comments
 */
public class Processor {
    public static final int TYPE_BINARY = 1;
    public static final int TYPE_HEX = 2;
    public static final int TYPE_ASCII = 3;
    public static final int TYPE_HTML = 4;
    
    private Vector pluginChain = new Vector();
    private int inputType = -1;
    private int outputType = -1;
    private int keyType = -1;
    
    public void addPlugin(Plugin plugin) {
        this.pluginChain.add(plugin);
    }
    
    public void clearPlugins() {
        this.pluginChain.removeAllElements();
    }
    
    public void setInputType(int inputType) {
        this.inputType = inputType;
    }
    public void setOutputType(int outputType) {
        this.outputType = outputType;
    }
    public void setKeyType(int keyType) {
        this.keyType = keyType;
    }
    public String doAction(String in, String key) throws RuntimeException, FormatException {
        int[] data = null;
        int[] keyData = null;
        String result = null;
        if (inputType == -1) 
            throw new RuntimeException("Input type not set");
        if (outputType == -1)
            throw new RuntimeException("Output type not set");
        switch(inputType) {
            case TYPE_BINARY:
                data = Translator.binToByte(in);
                break;
            case TYPE_HEX:
                data = Translator.hexToByte(in);
                break;
            case TYPE_ASCII:
                data = Translator.asciiToByte(in);
                break;
            default:
                throw new RuntimeException("Unknown input type");
        }
        switch(keyType) {
            case TYPE_BINARY:
                keyData = Translator.binToByte(key);
                break;
            case TYPE_HEX:
                keyData = Translator.hexToByte(key);
                break;
            case TYPE_ASCII:
                keyData = Translator.asciiToByte(key);
                break;
            default:
                throw new RuntimeException("Unknown input type");
        }
        for (Iterator i = this.pluginChain.iterator(); i.hasNext(); ) {
            data = ((Plugin) i.next()).doAction(data, keyData);
        }
        switch(outputType) {
            case TYPE_BINARY:
                result = Translator.byteToBin(data);
                break;
            case TYPE_HEX:
                result = Translator.byteToHex(data);
                break;
            case TYPE_ASCII:
                result = Translator.byteToAscii(data);
                break;
            case TYPE_HTML:
                result = Translator.byteToPrintableAscii(data);
                break;
            default:
                throw new RuntimeException("Unknown input type");
        }
        return result;
    }
}
