//Copyright (C) 2004, Brian Enigma <enigma at netninja.com>
//This file is part of MagicCodes.
//
//MagicCodes is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//MagicCodes is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with Foobar; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
package org.ninjasoft.magiccodes.plugins;

import java.io.*;

/**
 * Plugin to analyze letter frequency
 * @author enigma
 */
public class AnalyzeFrequency implements Plugin {
	public String getName() {
		return "Analyze Frequency";
	}
	public String getDescription() {
		return "Analyzes Letter Frequency";
	}
	public boolean usesKey() {
		return false;
	}
    public boolean isInformational() {
        return true;
    }
	public int[] doAction(int[] in, int[] key) {
        int frequencies[] = new int[256];
        int max = 0;
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        // Zero out everything (not REALLY necessary in Java, but still good practice)
        for (int i=0; i<frequencies.length; i++)
            frequencies[0] = 0;
        // Count everything
        for (int i=0; i<in.length; i++) {
            int letter = in[i] % 256;
            max = Math.max(max, ++frequencies[letter]);
        }
        // Get the results
        try{
            out.write("Letter frequencies:\n".getBytes());
            // Yeay for Bubble Sort/Search...
            for (int i = max; i> 0; i--) {
                for (int j = 0; j < frequencies.length; j++) {
                    if (frequencies[j] == i) {
                        String hexCode = Integer.toString(j, 16);
                        if (hexCode.length() == 1)
                            hexCode = "0" + hexCode;
                        out.write("Character 0x".getBytes());
                        out.write(hexCode.getBytes());
                        out.write(" (ASCII ".getBytes());
                        if ((j >= 0x20) && (j <= 0x7E)) {
                            out.write("\"".getBytes());
                            out.write((char) j);
                            out.write("\")         ".getBytes());
                        }else{
                            out.write("unprintable) ".getBytes());
                        }
                        out.write(Integer.toString(frequencies[j]).getBytes());
                        out.write("\n".getBytes());
                    }
                }
            }
        }catch(IOException e){
            e.printStackTrace();
        }
        // Convert to result
        int[] result = new int[out.size()];
        byte[] data = out.toByteArray();
        for (int i=0; i<data.length; i++)
            result[i] = data[i];
		return result;
	}
}
