// Copyright (C) 2004, Brian Enigma <enigma at netninja.com>
// This file is part of MagicCodes.
//
// MagicCodes is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// MagicCodes is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Foobar; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
package org.ninjasoft.magiccodes.plugins;

import java.text.DecimalFormat;

/**
 * Plugin for performing ROT-N on text
 * @author enigma
 */
public class RotN implements Plugin {
    private DecimalFormat format = new DecimalFormat("00");
    public String getName() {
        return "ROT-N";
    }
    public String getDescription() {
        return "Performs ROT-N text rotations";
    }
    public boolean usesKey() {
        return false;
    }
    public boolean isInformational() {
        return true;
    }
    public int[] doAction(int[] in, int[] key) {
        StringBuffer result = new StringBuffer();
        for (int rot=0; rot<=26; rot++) {
            result.append("ROT-");
            result.append(format.format(rot));
            result.append(": ");
            for (int i=0; i<in.length; i++) {
                int c = in[i];
                if ((c >= 'a') && (c <= 'z'))
                    c = (c - 'a' + rot) % 26 + 'a';
                else if ((c >= 'A') && (c <= 'Z'))
                    c = (c - 'A' + rot) % 26 + 'A';
                else if ((c >= ' ') && (c <= '~'))
                    ;
                else
                    c = 0;
                result.append((char) c);
            }
            result.append("\n");
        }
        int[] resultArray = new int[result.length()];
        for (int i=0; i<resultArray.length; i++)
            resultArray[i] = result.charAt(i);
        return resultArray;
    }

}
